@@ -1,4 +1,12 @@
-﻿namespace LibMC.Properties {
+﻿/**
+ * \brief      Namespace for the .NET wrapper properties class.
+ * 
+ * Any user or global properties that should preserved from session to
+ * session can be added here through the designer. There are currently
+ * no properties in use.
+ */
+namespace LibMC.Properties
+{
     
     
     // This class allows you to handle specific events on the settings class:
